
%%                                                 DEFAULT INPUT VARIABLES 
%                                                             for STAGplot

function [IN,PLOT,SWITCH,TOPO,STYLE,SAVE] = f_defaults(SAVE)
    if ~exist('STAGplot','file'); f_INSTALL; end

    %% DEBUGGING
    SWITCH.verbose              =   logical(0);                         %switch for extended display output
    SWITCH.spPause              =   0.0;                                %pausing after subplot creation (might help with shifted subplots MatLab problem)
    
    %% INPUT FILE(S)
    IN.name                     =   { 'test' 'test'};                   %filename; it's size controls the # of subplots
    IN.number                   =   [   1    1 ];                       %filenumber
    IN.parameter                =   [  	11   11 ];                      %parameter dimensionalisation (see f_dimParameter)
    IN.folder                   =   {'/work/stagyy/' '/work/stagyy/'};  %file directory
%     PLOT.titleString            =   {'XXX' 'XXX' 'XXX'  };
%     PLOT.legendString           =   {'XXX' 'XXX' 'XXX'  };

    SWITCH.GeodynamicCode       =   'StagYY';                           %to use StagLab with a different code, run and adjust at locations of error messages
    SWITCH.Precision            =   {'single'};                         %input data precision: 'single' or 'double'
    
    PLOT.caseColor              =   [ 0.4 0.4 0.4   ;  0.8 0.4 0.0  ;  0.8 0.0 0.0];
    PLOT.lineStyle              =   {'-'    '--'    ':'};
    PLOT.lineWidth              =   [ 1.25   1.25   1.25  ];
    PLOT.startGradColor         =   [0.7 0.7 0.7];  %starting color for gradual specific file coloring (e.g., for PlotInPlot)
    
    %% DIMENSIONALISATION
    SWITCH.dim                  =   logical(0);   	%converts to dimensional output as set in f_dimParameter.m
    SWITCH.modelSetup           =   'standard';   	%general model parameter setup; see f_dimParameter.m

    %% SUBPLOT LAYOUT
%    PLOT.subplotLayout          =   [2 2];        %manually set subplot layout; only valid if uncommented; [z x]
    PLOT.reverseLayout          =   false;          %e.g., plot 3x2 instead of 2x3
    SWITCH.timeEvolution        =   logical(0);     SWITCH.timeDirection = 'topbot'; %'topbot', 'leftright'
    SWITCH.insertRectangles     =   logical(1);     %adds light rectangles to connect subplots

    %% POSITIONING
    SWITCH.figurePosition       =   'auto';         %'auto' or set manually by e.g., [47 1 1300 350]
    PLOT.shiftLeft              =   0;              %shift subplot positions closer or further away from each other
    PLOT.shiftUpward            =   0;          
    
    %% COLORBAR
    SWITCH.Colorbar             =   logical(1);     
        IN.constantColorbar     =   logical(0);  
      	PLOT.cbPos              =   'right';        %'right' 'bottom'
    	PLOT.cbLabelPos         =   'right';        %'right' 'top'  
        SWITCH.ColormapAll    	=   {'auto'  'noflip'}; %e.g. jet, copper, bone, pink, gray, br, bwr, w_jet, wblr, brWbl, blWgr // flip or noflip
        SWITCH.cbarLimitIndicTop=   [0]; SWITCH.cbarLimitColorTop = [0.81 0.81 0.81]; %adds specific color to top/bot
        SWITCH.cbarLimitIndicBot=   [0]; SWITCH.cbarLimitColorBot = [0.81 0.81 0.81]; %indicating exceeding values (only one number sets it for all plots, otherwise specify for every subplot using [0 1 0 ...])
%     %use these to set the min/max colorbar values of each field:
%     IN.graph_min            =   -15;          
%     IN.graph_max            =   15;
%     IN.topo_min             =   -0.3;
%     IN.topo_max             =   0.3;
%     IN.isotopo_min      	  =   -0.3;
%     IN.isotopo_max      	  =   0.3;
%     IN.restopo_min      	  =   -0.3;
%     IN.restopo_max      	  =   0.3;
%     IN.dyntopo_min      	  =   -0.3;
%     IN.dyntopo_max      	  =   0.3;
%     IN.T_min                =   300;
%     IN.T_max                =   1150;
%     IN.Tres_min             =   -400;
%     IN.Tres_max         	  =   4000;
%     IN.eta_min              =   1e19; 
%     IN.eta_max              =   1e28; 
%     IN.str_min              =   0;
%     IN.str_max              =   5.8;
%     IN.nstr_min             =   -800;
%     IN.nstr_max             =   800;
%     IN.rho_min              =   3200;
%     IN.rho_max              =   3450;
%     IN.P_min                =   0;            
%     IN.P_max                =   140;
%     IN.diss_min             =   0;            
%     IN.diss_max             =   5e-6;
%     % ...and each individual subplot use brackets:
%     IN.edot_max             =   [3e-20  1.05e-18];
%     IN.edot_min             =   [0      0       ];
%     IN.vel_min              =   -0.01;
%     IN.vel_max              =   0.01;
         
    %% PLOT STYLING
    SWITCH.stylePlots           =   logical(1);     %style plot
    STYLE.AllFontName           =   'Open Sans';  	%e.g. 'Helvetica','Corbel','Eurostyle','ETH Light','Open Sans'
    STYLE.keyFontSize           =   10;
    SWITCH.styleBackground      =   logical(1);  	%style plot background of graph supplots
    SWITCH.styleLegend          =   logical(1);     %style legends
        STYLE.fitLegendPosition	= 	logical(1);   	%fixes legends tightly to the axes
    SWITCH.simplify             =   logical(1);     %simplify plot layout
    
    PLOT.Style                  =   'pcolor';       %use either 'contour' or 'pcolor'
    PLOT.numContours            =   100;            %#contours in contour plots
    SWITCH.closeCylinder        =   logical(1);     %adds one row of data points to visually close the cylindrical plots
    %axes
    SWITCH.axis_off             =   logical(0);
    SWITCH.onlyXaxis            = 	logical(1);     %currently only implemented for cylindrical plots
    SWITCH.axisEqual            =   logical(1);
    SWITCH.setAxisLimit         =   logical(0);     SWITCH.axisLimit = [500 1300 -5 200; 1500 2300 -5 200; ...
                                                                500 1300 -5 200; 1600 2400 -5 200];   %zoom for big plots
    SWITCH.actualDepth          =   logical(1);     %accounts for sticky air - only applied for sticky air cases
    SWITCH.tickDir              =   'out';          %'in' or 'out' - tickmarks location
    %colours
    STYLE.colorMode             =   'light';        %'light' or 'dark' background
    STYLE.keyColor              =   [0.5 0.5 0.5];  %key colour used for text and axes
    STYLE.keyLineColor          =   [0.1 0.1 0.1];  %key line colour in graph plots
    STYLE.keyLineWidth          =   1.0;            %key line width in graph plots
    
    %% ANNOTATIONS
    SWITCH.annotation           =   logical(1);     
        STYLE.annotationLocation= 'botLeft';        %e.g., 'topOutTop','topOutCorner','topLeft','botLeft','topRight','botRight'
        PLOT.annotation         =   {'a' 'b' 'c' 'd' 'e' 'f' 'g' 'h' 'i' 'j' 'k' 'l' 'm' 'n' 'o' 'p'};  %subplot annotation strings
        PLOT.annIfMoreThanOne   =   logical(1);     %add annotation only if more than 1 subplot
    SWITCH.title                =   logical(1);     
        PLOT.titleOnlyTime      =   logical(0);   	%for a title that includes only time
%         PLOT.titleString      =   {'title 1'  'title 2' 'title 3' '' '' '' '' '' '' '' '' ''  };	%adds manual title string if uncommented
    SWITCH.texting              =   logical(0);     %write out resolution and max values of the field
    SWITCH.cylindricalCenterText = logical(1);      %adds #gridpoints to the center of the cylinder
    
    %% PLOT ADDITIONS
    PLOT.zoom                   =   logical(0);     %adds an additional plot for a close up
        PLOT.zoomPos            =   'northwest';
        PLOT.zoomVal            =   [2500 3500 -50 500 ; 900 1900 -50 500 ; 1300 2300 -50 500]; %...with the corresponding values
    PLOT.zProfile               =   logical(0);     %takes profile at non-dim value of x (or z if PLOT.z_prof uncommented)
        PLOT.x_prof             =   1.01;   
        %PLOT.z_prof             =   0.1;

    %% 3-D CARTESIAN MODEL: ISOSURFACE  -----------------------------------
    PLOT.cameraPosition         =   [59240 35752 -37631];  	% camera position for 3-D figures; standard is top: [59240 35752 -37631]; bot: [59240 35752 +37631]
    PLOT.cameraPosBotView       =   logical(0);       	%flips view to bottom up (only for 3-D box plots)
    PLOT.camProjection          =   'orthographic';  	%camera projection: either 'perspective' or 'orthographic'
    PLOT.lighting               =   'gouraud';          %lighting options, e.g., none, flat, gouraud
    PLOT.camlight               =   'headlight';     	%camlight options, e.g., headlight, left, right
    PLOT.opacity                =   [0.3 0];         	%opacity of the isosurfaces   1: last one is opaque 0: last one is also transparent]
    PLOT.isoVal                 =   [0.2 0.45 0.8];     %values of isosurfaces (ranging between 0 and 1)

    PLOT.isoValSpecial          =   [];                 %plots nicely colored isosurface
    PLOT.isoColorSpecial        =   [1.0 0.5 0.4];      %e.g., blue: [0.5 0.6 1.0] or red: [1.0 0.5 0.4]
    PLOT.opacitySpecial         =   [1];                %opacity of the special isosurface(s)
    
    %% 3-D CARTESIAN MODEL: SLICING  --------------------------------------
    PLOT.Slices                 =   logical(0);     %Switch to add slices
        PLOT.sliceX             =   [50];           %in plotting values e.g.,[0:0.01:1]
        PLOT.sliceY             =   [50];
    	PLOT.sliceZ             =   [2850];
        PLOT.SliceOpacity       =   0.5;

    PLOT.SliceSpecial           =   logical(0);
        PLOT.sliceXS            =   [];             %in plotting values
        PLOT.sliceYS            =   [];
        PLOT.sliceZS            =   [];
    
   	PLOT.sliceAddQuiver         =   logical(0);
        PLOT.sliceXV            =   [];             %in plotting values for Quiver
        PLOT.sliceYV            =   [];
        PLOT.sliceZV            =   [];
        
    PLOT.SliceAddTopo           =   logical(0);
%                                 TOPO.surf=logical(1); TOPO.cmb=logical(0);
%                                 TOPO.true  =logical(0);
%                                 TOPO.smooth=logical(1);
%                                 SWITCH.ColormapAllT = {'topo5'  'noflip'};
%                                 SWITCH.constantColorbarT = logical(1);

    PLOT.sliceXT                =   [];             %in plotting values
    PLOT.sliceYT                =   [];
    PLOT.sliceZT                =   [0.01  1.0];    %[surf cmb]
    PLOT.opacity_plotT          =   1.0;
    
    
    %% YINYANG MODELS  ----------------------------------------------------
    SWITCH.yyPlotMode           =   'map';         %'isosurface' or 'map' or 'mapOnSphere'
    
    %% YINYANG MODEL: ISOSURFACE ------------------------------------------ %NOT FULLY IMPLEMENTED YET
    % see 3-D Cartesian Model plot options
    
    %% YINYANG MODEL: MAPS  -----------------------------------------------
    PLOT.yyZlevelV              =   [0.02 0.69 0.91];  	%non-dim whole-domain depth: 0.94 (plates); ~0.85 (slabs)
    PLOT.yyNumSlices            =   1;                  %number of horizontal slices per subplot
    
    SWITCH.yyFlipVertical       =   logical(1);     	% flips map vertically to be according to spherical plot

    PLOT.yyOriginLong           =   -180;            	% origin longitude in degrees
    SWITCH.yyLimitMap           =   logical(0);
      	PLOT.yyLimitN           =   45;
      	PLOT.yyLimitS           =   -45;
     	PLOT.yyLimitW           =   -45;
      	PLOT.yyLimitE         	=   45;
    
    SWITCH.yyLabelMeridian      =   'off';
    SWITCH.yyLabelParallel      =   'on';       
    PLOT.yyPlabelTicks          =   [-75 -60 -45 -30 -15 0 15 30 45 60];
    PLOT.yyPlabelLocation       =   'west';  %east | {west} | prime | scalar longitude

    PLOT.yyAnnTitle             =   logical(1);
    PLOT.yyAnnDepth             =   logical(1);
    PLOT.yyDepthGraph           =   logical(0);         % adds a small depth graph - DEOSN'T WORK YET WITH AXIS STUFF IN STAGPLOT........

    SWITCH.yyOnlyTopQuiver      = 	logical(0);    	% puts arrows only on uppermost slice
    SWITCH.yyOnlyBotQuiver      =  	logical(0);        % puts arrows only on lowermost slice
    
    %% --------------------------------------------------------------------    
    
    %% POST-PROCESSING
    SWITCH.plateDiagnostics     =   logical(0);
    SWITCH.mantleDiagnostics    =   logical(0);
    PLOT.indicateTrench         =   logical(0);     PLOT.IndicationDepth = 0; %-0.0263; %[nd]
    PLOT.indicateRidge          =   logical(0);     PLOT.IndicationSize = 20;
    PLOT.indicateUpperPlate     =   logical(0);     PLOT.PlateIndSize = 6; %upper plate indication
    PLOT.indicateLowerPlate     =   logical(0);     %lower plate indication
    PLOT.indicatePlateCore      =   logical(0);     %depth of the plate core
    PLOT.indicateSlabDip        =   logical(0);
    PLOT.indicateSlabTip        =   logical(0);
    PLOT.indicatePlateFit       =   logical(0);     %fit of the subducting plate
    PLOT.indicateUPtilt         =   logical(0);     %upper-plate tilt
    PLOT.indicateBending        =   logical(0);
    PLOT.indicatePlumes         =   logical(0);     %only for yy cases 
       	PLOT.pHot               =   0.4;            %fraction of difference Tmax-Tmean and Tmin-Tmean, resp. (T_threshold = Tmean+p_hot*(Tmax-Tmean) )
        PLOT.pCold              =   0.4;            %fraction of difference Tmax-Tmean and Tmin-Tmean, resp. (T_threshold = Tmean+p_hot*(Tmax-Tmean) )
      	PLOT.plumeColorHot      =   'r'; 
        PLOT.plumeColorCold     =   'b';
     	PLOT.onlyBotPlumes      =   logical(0);    %for YY-map: only plot in bottom slice
      	SWITCH.savePlumes       =   logical(0);    %saves plume output

    %% SAVING FIGURE
    SAVE.Plot                   =   logical(0);     %saves plot directly to directory
        SAVE.png                =   logical(1);     SAVE.pngResolution = '-m4.0';	
        SAVE.jpg                =   logical(0); 
        SAVE.eps                =   logical(0); 
        SAVE.pdf                =   logical(0); 
        SAVE.overwrite          =   logical(0);
        SAVE.writeDirectory     =   'auto';         %'auto': save to standard folder (.../+im/...); otherwise use e.g., '/work/stagyy/'
        
    %% SAVING MOVIE
    SAVE.Movie                  =   logical(0);     %saves movie directly to directory
        SAVE.avi                =   logical(1);
        SAVE.mj2                =   logical(0);
        SAVE.mp4                =   logical(0);
        SAVE.m4v                =   logical(0);
        SAVE.movFrameRate       =   10;            	%10 (default) | frames per second
        SAVE.movQuality         =   75;             %75 (default) | integer in the range [0,100]
        
    %% SAVE DATA
    SAVE.field                  =   logical(0);     SAVE.mat = logical(1); SAVE.dat = logical(0);  %saves plotted 2-D/3-D field according to f_saveField
    SAVE.tectonicData           =   logical(0);     %saves tectonic data (see list of data in STAGplot.m)
    SAVE.timeDat                =   logical(0);     %saves time [nd, seconds, years]
    TOPO.saveData               =   logical(0);     %saves topo: [x, topo, topoSmooth]
    SAVE.plateVelocityData      =   logical(0);     %saves plate velocity vector data: []
    SWITCH.trackC               =   logical(0);     %tracks and saves specified point of the composition field
    SAVE.subductionZoneData     =   logical(0);     %OLD (use SAVE.tectonicData instead!): saves subduction zone data: [x-trench, subduction-polarity, trench/UP-vel, LP-vel, Convergence-vel,...]
        
    %% PERFORMANCE
    SWITCH.ReduceSize           =   logical(0);   	%reduces matrix size for faster plotting
    SWITCH.quickRun             =   logical(0);     %adjust parfile switches for quick runtime to e.g. save data efficiently

    %% DATA ALTERATION
    %SWITCH.flipDataHorizontally =   logical(0);     %NOT IMPLEMENTED YET! flips data horizontally (for binary StagYY output only)
    
    %% SPECIAL PLOTTING BEHAVIOUR
    SWITCH.PlotInPlot           =   logical(0); 	%for every field plots data from all files onto same plot  *not implemented for all fields yet*
    SWITCH.plotGraphVsTime      =   logical(0);     %plots in 2-D, a selected graph (x) vs. time (y)  *only for topography, yet*
    SWITCH.plotDifference       =   logical(0);     %plots difference between two fields
        
    %% FIELDS TO PLOT
    PLOT.Temperature            =   logical(1);
    PLOT.RegionalResidualT      =   logical(0);
    PLOT.HorizResidualT         =   logical(0);
    PLOT.HorizBandResidualT     =   logical(0);
    PLOT.GlobalResidualT        =   logical(0);
    PLOT.Composition            =   logical(0);
    PLOT.Density                =   logical(0);
    PLOT.Viscosity              =   logical(0);  IN.eta_log = logical(1);
    
    PLOT.Velocity               =   logical(0);
    PLOT.VelocityX              =   logical(0);
    PLOT.VelocityZ              =   logical(0);
    PLOT.UpDownWelling          =   logical(0);  %plots active and passive up- and down-welling
    PLOT.Pressure               =   logical(0);  %total pressure
    PLOT.HeatFlux               =   logical(0);  SWITCH.plotFIELDtrue=logical(1); SWITCH.plotFIELDsmooth=logical(0); SWITCH.plot3Dfield2D=logical(0);
    PLOT.StrainRate             =   logical(0);  IN.edot_log=logical(0);   %strain rate
    PLOT.Stress                 =   logical(0);  IN.str_log=logical(0);  %logarithmic stress
    PLOT.StressX                =   logical(0);  %principle horizontal (x) stress component
    PLOT.StressZ                =   logical(0);  %principle radial stress component
    PLOT.NormalStress           =   logical(0);  %sigma_zz actually
    PLOT.ViscDissipation     	=   logical(0);  %sigma_ij*edot_ij

    PLOT.Topo                   =   logical(0);  TOPO.ascii=logical(0); TOPO.cmb=logical(0); TOPO.surf=logical(1);
      	TOPO.color              =   [0.81 0.81 0.81]; 
        TOPO.opacity            =   0.9; 
      	TOPO.areaFill           =   'down';         %filled area in topography plot: 'none', 'down', 'updown'
      	TOPO.water              =   true;           %fills negative levels in topography plot with "water", i.e., a blue area
      	SWITCH.plotTOPOtrue     =   logical(0);
     	SWITCH.plotTOPOsmooth   =   logical(1);
        TOPO.indicateComponents = 	logical(0); 
        TOPO.difference         =   'comp'; %'comp' or 'diff'
      	SWITCH.plot3Dtopo2D     =   logical(0);     %for 3-D plots
        TOPO.exagFactor         =   1;              %for 3-D plots
    PLOT.IsoTopo                =   logical(0);
        TOPO.normIsoTopoToZero  =   logical(1);     %set mean of isostatic component to zero due to volume conservation in an incompressible mantle
    PLOT.ResTopo                =   logical(0);
    PLOT.DynTopo                =   logical(0);  
        TOPO.dynTOPOsmooth      =   logical(1);
    PLOT.Geoid                  =   logical(0);  TOPO.GEOIDcmb=logical(0); TOPO.GEOIDsurf=logical(1);
    
    PLOT.DefMechanism           =   logical(0);
    PLOT.Toroidal               =   logical(0);
    PLOT.Poloidal               =   logical(0);
        
    PLOT.Basalt                 =   logical(0);  %individual compositions
    PLOT.Harzburgite            =   logical(0);
    PLOT.ContCrust              =   logical(0);
    PLOT.Air                    =   logical(0);
    PLOT.Primordial             =   logical(0);
    PLOT.Water                  =   logical(0);
    PLOT.Melt                   =   logical(0);
    
    %these are not implemented yet:
    PLOT.DynPressure            =   logical(0); %...
    PLOT.MeltFrac               =   logical(0); %...
    PLOT.Crust                  =   logical(0); %...
    
    %% GRAPHS TO PLOT
    PLOT.ParTable               =   logical(0);  %plots a table with dynamic parameters
    PLOT.PlateSketch            =   logical(0);  %plot sketch of plates with subduction parameters indication
    PLOT.PlateVh                =   logical(0);
    PLOT.IsolineTopo            =   logical(0);  %e.g., for LAB topography; uses same parameter input as for lithoThickness
    PLOT.CustomGraph            =   logical(0);  %plot graph of any data versus any data (that has been saved previously with StagLab)
        PLOT.CustomGraphName    =   {'custom'};  %indicate which graph(s) to plot, use 'custom' for a custom graph specified in f_plotCustomGraph.m or any pre-specified graph there
    
    %% SPECIAL PLOTS
    PLOT.Grid                   =   logical(0);  PLOT.nCoarserGrid 	= 1; %plots grid
    PLOT.Streamfunction       	=   logical(0);  PLOT.streamdata = 'psi'; %psi (streamfunction) or phi (v-potential)
    PLOT.Streamline             =   logical(0);  %separate figure for streamline
    PLOT.Quiver                 =   logical(0);  %separate figure for velocity
    PLOT.PrincStressDirection   =   logical(0);  %separate figure for principle stress direction
     
    %% FIELD PLOT ADDITIONS
    IN.grid_T                   =   logical(0);  % add grid to fields
    IN.grid_eta                 =   logical(0);
    IN.grid_str                 =   logical(0);
    IN.grid_edot                =   logical(0);
    
    IN.streamline_T             =   logical(0);  % add streamline plot to fields
    IN.streamline_eta           =   logical(0);
    IN.streamline_str           =   logical(0);  PLOT.streamStartline = [0.4 0.4; 0.0 0.0; 0.0 0.9]; %[x1 x2; y1 y2; z1 z2]; vary <0-1>
    
    IN.streamfun_T              =   logical(0);  % add streamfunction plot to fields
    IN.streamfun_eta            =   logical(0);  IN.streamNumContours = 17;
    IN.streamfun_str            =   logical(0);  PLOT.streamColor   = [0.81 0.81 0.81]; PLOT.streamColoured = 'false'; %'false','bwr','br','blgr' or any colormap (needs 'freezeColors.m')
    IN.streamfun_rho            =   logical(0);  PLOT.streamWidth   = 0.2;
    IN.streamfun_v              =   logical(0);
    IN.streamfun_edot           =   logical(0);

    IN.quiver_T                 =   logical(0);  % add quiver plot to fields
    IN.quiver_eta               =   logical(0);  SWITCH.quiverNumArrows = 'auto'; %'auto' or 'manual': reduces number of arrows
    IN.quiver_str               =   logical(0);  IN.quiverNumDel    = 14;
    IN.quiver_psi               =   logical(0);  IN.quiverScale     = 17;
    IN.quiver_rho               =   logical(0);  PLOT.quiverColor   = [0.81 0.81 0.81];
    IN.quiver_nstr              =   logical(0);  PLOT.quiverWidth   = 0.25;
    IN.quiver_edot              =   logical(0);
    
    IN.defmech_T                =   logical(0);  %1: diffusion creep, 2: dislocation creep, 3: plasticity, 4: visc. cutoff
    IN.defmech_eta              =   logical(0);  IN.defmechContours	= [2 3 4];  %1.3: 1/3, 1.1: 1/10 of weakening from dislocation creep
    IN.defmech_str              =   logical(0);  PLOT.defmechColor	= [0.9 0.1 0.1; 0.7 0.0 0.0; 0.9 0.1 0.1; 0.1 0.9 0.1; 0.1 0.1 0.9];
    IN.defmech_edot             =   logical(0);
    
    IN.lithoThickness_T         =   logical(0);  PLOT.LTfieldContour= 'Temperature';
    IN.lithoThickness_eta       =   logical(0);  IN.lithoTisovalue 	= 1600; 
    IN.lithoThickness_nstr      =   logical(0);  IN.lithozmax     	= 500;
    
    IN.fieldContour_T           =   logical(0);  PLOT.fContourField	= 'Temperature';
    IN.fieldContour_eta         =   logical(0);  IN.fContourIsovalue= 1600;
    IN.fieldContour_nstr        =   logical(0);
    IN.fieldContour_vx          =   logical(0);
    IN.fieldContour_str         =   logical(0);
    IN.fieldContour_edot        =   logical(0);
    IN.fieldContour_vdiss       =   logical(0);
    
    IN.princStress_T            =   logical(0);  % add quiver plot to fields
    IN.princStress_eta          =   logical(0);  SWITCH.princStressNumArrows = 'auto'; %'auto' or 'manual': reduces number of arrows
    IN.princStress_str          =   logical(0);  IN.princStressNumDel    = 5;
    IN.princStress_psi          =   logical(0);  IN.princStressScale     = 2;
    IN.princStress_rho          =   logical(0);  PLOT.princStressColor   = [0.91 0.61 0.61];
    IN.princStress_nstr         =   logical(0);  PLOT.princStressWidth   = 0.25;
    IN.princStress_edot         =   logical(0);
    
    PLOT.Plume                  =   logical(0);	 %!!! not implemented yet - single plot of plumes..................
    IN.plume_T                  =   logical(0);	 % add plume plot addition to fields
    IN.plume_eta                =   logical(0);
    IN.plume_str                =   logical(0);
    IN.plume_rho                =   logical(0);
    IN.plume_v                  =   logical(0);
    IN.plume_edot               =   logical(0);
    
    TOPO.field                  =   logical(0);  % add topography to field plots
        TOPO.line               =   logical(1); 
        TOPO.area               =   logical(1); 
        PLOT.hatchAir           =   logical(1);
      	TOPO.lineColor          =   [0.2 0.2 0.2]; 
        TOPO.lineWidth          =   0.25;
end

