
%%                                                 DEFAULT INPUT VARIABLES
%                                                            for STAGrprof

function [IN,PLOT,SWITCH,STYLE,SAVE] = f_defaultsRprof
if ~exist('STAGrprof','file'); f_INSTALL; end

%% DEBUGGING
SWITCH.verbose                  =   logical(0);                 %switch for extended display output

%% INPUT FILE(S)
SWITCH.GeodynamicCode           =   'StagYY';                 	%to use StagLab with a different code, run and adjust at locations of error messages
IN.name                         =   {'test'  'test'  };         %filename
IN.number                       =   [   0    1 ];
IN.parameter                    =   [  	11   ];                 %see f_dimParameter.m for more details
IN.folder                       =   {'/work/stagyy/'};

%% DIMENSIONALISATION
SWITCH.dim                      =   logical(0);
    SWITCH.modelSetup           =   'standard';

%% SAVING
SAVE.Plot                       =   logical(0);                 %saves plot directly to directory 
    SAVE.jpg                    =   logical(0);
    SAVE.eps                    =   logical(0);
    SAVE.pdf                    =   logical(0);
    SAVE.png                    =   logical(1);     
        SAVE.pngResolution      =   '-m4.0';
    IN.saveString               =   '+rprof';

%% STYLING
SWITCH.stylePlots               =   logical(1);
SWITCH.styleBackground          =   logical(1);
SWITCH.styleLegend              =   logical(1);
SWITCH.simplify                 =   logical(1);
%font
STYLE.AllFontName               =   'Open Sans';                %e.g. 'Helvetica','Corbel','Eurostyle','ETH Light','Open Sans'
STYLE.keyFontSize               =   10;
%colours
STYLE.colorMode                 =   'light';                    %'light' or 'dark' figure background
STYLE.keyColor                  =   [0.5 0.5 0.5];              %key colour used for text and axes
%lines
IN.LineWidthPlot                =   1.0;

%% AXES DETAILS
IN.constantAxis                 =   logical(0);
IN.reverseYaxis                 =   logical(1);

%% LABELLING
%PLOT.titleString                =   {'free-slip surface' 'free surface'}; %manual title if uncommented
SWITCH.title                    =   logical(0);
SWITCH.annotation               =   logical(1);     
    STYLE.annotationLocation    =   'botLeft';                  %e.g., 'topOutTop','topOutCorner','topLeft','botLeft','topRight','botRight'
    PLOT.annotation             =   {'a' 'b' 'c' 'd' 'e' 'f' 'g' 'h' 'i' 'j' 'k' 'l' 'm' 'n' 'o' 'p'};  %subplot annotation strings
    PLOT.annIfMoreThanOne       =   logical(1);                 %add annotation only if more than 1 subplot

%% PLOT ADDITIONS
SWITCH.d_eta                    =   logical(0);                 %displays viscosity increase with depth
PLOT.parameterRange             =   logical(1);                 %plotting mean, min & max
    PLOT.rangeAsArea            =   logical(1);
IN.showLegend                   =   logical(0);
    PLOT.LegendLocation         =   'SouthEast';

%% PARAMETER(S) TO PLOT
PLOT.Temperature                =   logical(1);         IN.T_logx       = 0;  %*
PLOT.Viscosity                  =   logical(1);         IN.eta_logx     = 1;  %*
PLOT.Density                    =   logical(0);         IN.rho_logx     = 0;
PLOT.Stress                     =   logical(1);         IN.str_logx     = 0;  %*
PLOT.StrainRate                 =   logical(0);         IN.edot_logx    = 1;  %*
PLOT.Velocity                   =   logical(0);         IN.v_logx       = 0;
PLOT.VerticalVelocity           =   logical(0);     	IN.vz_logx      = 0;
PLOT.HorizontalVelocity         =   logical(1);         IN.vh_logx      = 0;  %*

PLOT.HorizVorticity             =   logical(0);         IN.w_logx       = 0;
PLOT.VertVorticity              =   logical(0);         IN.w_logx       = 0;
PLOT.Divergence                 =   logical(0);         IN.div_logx 	= 0;

PLOT.Advection                  =   logical(0);         IN.Hadv_logx    = 0;
PLOT.Diffusion                  =   logical(0);         IN.Hdiff_logx   = 0;
PLOT.InternalHeating            =   logical(0);         IN.Rh_logx      = 0;  %*
PLOT.ViscDissipation            =   logical(0);         IN.vd_logx      = 0;  %*
PLOT.AdiabaticHeating           =   logical(0);         IN.ah_logx      = 0;  %*

PLOT.Heatflux                   =   logical(0);         IN.HF_logx      = 0;  %*

PLOT.Crust                      =   logical(0);         IN.c_logx       = 0;
PLOT.Air                        =   logical(0);         %log x-axis is switched on with IN.c_logx
PLOT.ContCrust                  =   logical(0);         % "
PLOT.Primordial                 =   logical(0);         % "
PLOT.Fluid                      =   logical(0);         % "
PLOT.Metal                      =   logical(0);         % "

IN.plates_analyse               =   logical(0);         IN.z_level  = 0.01; %0.01 (surface); ~0.15 (slabs)

PLOT.Toroidal                   =   logical(0);         IN.To_logx      = 0;  %*
PLOT.ToroidalRMS                =   logical(0);         IN.To_logx      = 0;
PLOT.Poloidal                   =   logical(0);         IN.Po_logx      = 0;  %*
PLOT.PoloidalRMS                =   logical(0);         IN.Po_logx      = 0;
PLOT.Mobility                   =   logical(0);         IN.M_logx       = 0;
PLOT.f80                        =   logical(0);         IN.f80_logx     = 0;
PLOT.f90                        =   logical(0);         IN.f90_logx     = 0;

%% COLOUR SET FOR MULTIPLE LINES
PLOT.ColorVector                =   [
    0.0 0.0 0.0
    0.0 0.45 0.74
    0.49 0.18 0.56
    0.85 0.32 0.1
    0.93 0.69 0.13
    1.0 0.0 1.0
    0.0 0.0 0.0
    0.0 0.0 0.0
    0.0 0.0 0.0
    0.0 0.0 0.0
    ];

%% DEFINE Y-PARAMETER
PLOT.ParameterY                 =   1;

end









