
%%                                                         FILE FINDER 4.01
%                                                   for binary StagYY data
% input:
%  FILE.name
%  FILE.number
%  FILE.stemRead

% checks for folder structure:
%  /folder/+op/<filename>...
%                                                Fabio Crameri, 29.03.2017

%% NOTES
% only searches temperature files.............

function [FILE] = f_fileFinder(FILE,SWITCH)
%% DEFAULTS
if ~exist('SWITCH','var') || ~isfield(SWITCH,'GeodynamicCode'); SWITCH.GeodynamicCode = 'StagYY'; end
if ispc; slash = '\'; else; slash = '/'; end
stemReadOriginal    = FILE.stemRead;

%% DECIDE FOR INPUT-DATA FOLDER
if exist(strcat(stemReadOriginal,'+op',slash,FILE.name,slash),'dir') %check for .../+op/<filename>/... folder structure
    FILE.stemRead   = strcat(FILE.stemRead,'+op',slash);
end
%% DECIDE FOR OUTPUT-FILES FOLDER
if exist(strcat(stemReadOriginal,'+im',slash,FILE.name,slash),'dir') %check for .../+im/<filename>/... folder structure
    FILE.stemSave	= strcat(FILE.stemSave,'+im',slash);
end

%% CHECK FOR INPUT FILE
%check for current file
if strcmp(SWITCH.GeodynamicCode,'StagYY')
    numberingFormat = '00000';
    filetofindOrig 	= [FILE.stemRead,FILE.name,slash,FILE.name,'_t',numberingFormat]; %full file name for zero numbered Temperature file
    
    % elseif strcmp(SWITCH.GeodynamicCode,'->CODENAME<-')
    %filetofindOrig  = [FILE.stemRead,FILE.name,'/',FILE.name,'_t00000']; %full file name for zero numbered Temperature file
else
    error('Adjust here to use StagLab with output files from another geodynamic code.')
end
filetofind      = filetofindOrig;
filetofind2     = filetofindOrig;
nextfiletofind  = filetofindOrig;

fnumberString   = num2str(FILE.number);
if ~strcmp(filetofind(1,end-size(fnumberString,2)+1),'0'); error('Filenumber is too big!'); end
filetofind(1,end-size(fnumberString,2)+1:end) = fnumberString;

%already check for next file
fnumberString2  = num2str(FILE.number+1);
if ~strcmp(nextfiletofind(1,end-size(fnumberString2,2)+1),'0'); error('Filenumber is too big!'); end
nextfiletofind(1,end-size(fnumberString2,2)+1:end) = fnumberString2;

%% CONVERT FOR WINDOWS PC
if ispc %just to be sure
    filetofindOrig   = strrep(filetofind,'/','\');
    filetofind2      = strrep(filetofind,'/','\');
    filetofind       = strrep(filetofind,'/','\');
    nextfiletofind   = strrep(filetofind,'/','\');
end

%% IF FILE NOT FOUND CHECK FOR LATEST FILE
%scan from 0 to max
FILE.LastFile = false;
if ~exist(filetofind,'file')
    % check for last output file number
    for inum=FILE.number:-1:0
        fnumberString   = num2str(inum);
        filetofind2     = filetofindOrig;
        filetofind2(1,end-size(fnumberString,2)+1:end) = fnumberString;
        if exist(filetofind2,'file')
            FILE.number     = inum;
            fnumberString   = num2str(FILE.number);
            FILE.LastFile   = true; %last file that exists reached
            break  %exit loop
        end
    end
    
elseif ~exist(nextfiletofind,'file')
    FILE.LastFile = true; %last file that exists reached
end

%% ERROR MESSAGE IF NO FILE AT ALL IS NOT FOUND
if FILE.number==-1
    error(['File not found - Check file directory: ',filetofind])
end

%% DISPLAY INFO
disp(['Name:              ',FILE.name])
disp(['Number:            ',num2str(FILE.number)])
% disp(['Geodynamic Code:   ',SWITCH.GeodynamicCode])

%% ADDITIONAL OUTPUT
FILE.found      = [FILE.stemRead,FILE.name,slash,FILE.name,'_t',numberingFormat];
FILE.found(end-length(fnumberString)+1:end)      = fnumberString;
FILE.directory	= strcat(FILE.stemRead,FILE.name,slash);
if ispc %just to be sure
    FILE.found   	= strrep(FILE.found,'/','\');
    FILE.directory 	= strrep(FILE.directory,'/','\');
end
