
%%                                      PLOT horizontal PLATE VELOCITY 1.1

%                                                Fabio Crameri, 23.06.2014

%% NOTES
% add empty plot if 3-D, as not implemented yet..............
% CHECK AGAIN CAREFULLY (LITHOthickness and grid dimensions/labels).......
% make deriving lithosphere thickness (i.e., finding appropriate T value) automatically .....

function [vh_plate,PLOT,SAVE] = f_plotPlateVel(FIELD,GRID,SWITCH,SETUP,PLOT,FILE,STYLE,SAVE)

%% INPUT
lineCOLOUR0 = STYLE.keyLineColor; %Color line h. plate velocity
lineWIDTH0  = STYLE.keyLineWidth;

%% READ TEMPERATURE ---------------------------------------------------
% Read temperature field information
T_3D        = PLOT.T_3D;

%% READ HORIZONTAL VELOCITY ---------------------------------------------------
% Read horizontal velocity information
if strcmp(GRID.Dim,'2-D')   % in 2-D this is the horizontal velocity
    if isfield(PLOT,'VX_3D') && isfield(PLOT,'VY_3D') && isfield(PLOT,'VZ_3D')
        VX_3D = PLOT.VX_3D; VY_3D = PLOT.VY_3D; VZ_3D = PLOT.VZ_3D;
    else
        [~,~,~,~,VX_3D,VY_3D,VZ_3D,~,~,~]    = f_readStagYY(FILE.directory,FILE.name,FILE.number,'Velocity',SWITCH);
        if ischar(VX_3D); error(VX_3D); end
    end
    if size(VX_3D,1)==1 %exchange x and y
        dummy_3D = zeros(size(VX_3D,2),size(VX_3D,1),size(VX_3D,3));
        dummy_3D(:,1,:) = VX_3D(1,:,:);     VX_3D = dummy_3D;
        dummy_3D(:,1,:) = VY_3D(1,:,:);     VY_3D = dummy_3D;
        dummy_3D(:,1,:)	= VZ_3D(1,:,:);     VZ_3D = dummy_3D;
        dummy_3D = VX_3D; VX_3D = VY_3D; VY_3D = dummy_3D;
    end
    VH_3D = VX_3D;  %%% DEFINE HORIZONTAL VELOCITY
else
    error('3-D plate velocity plot not implemented yet!');
end
if strcmp(GRID.Type,'Cartesian')
    x2d(:,:,:)	= GRID.X_3Dp(:,:,:);   %in GRID.Xdim
    y2d(:,:,:) 	= GRID.Y_3Dp(:,:,:);   %in [whatever]
elseif strcmp(GRID.Type,'cylindrical')
    x2d(:,:,:)	= GRID.X_3Dsp(:,:,:);   %in GRID.Xdim
    y2d(:,:,:) 	= GRID.Y_3Dsp(:,:,:);   %in [whatever]
end
z2d(:,:,:) 	= GRID.Z_3Dp(:,:,:);   %in [whatever]

%--------------------------------
%% CHECK
% this needs actual depth switched on
if SWITCH.actualDepth || strcmp(SETUP.topBC,'free-slip') %nothing to be done
else
    error('Plotting plate velocity needs actual depth switched on!')
end
%--------------------------------
if strcmp(GRID.Type,'cylindrical')
    % RE-FLIP DEPTH VECTOR AND ACCOUNT FOR STICKY-AIR LAYER
    z2d = z2d +SETUP.d_air*GRID.dimFactor;  %set z=0 to real surface
    z2d = 1*GRID.dimFactor -z2d; % reverse z-axis  (1.)
end

%% DIMENSIONALIZATION
VH_3D       = VH_3D * SETUP.Vscale;  %[nd]->[cm/a]
T_3D        = T_3D * SETUP.deltaT; %[K]


%% CRITICAL VALUES to define lithosphere core
% LITHO.Tisovalue = PLOT.lithoThickness(1,1) /2;  %Temperature isovalue
% LITHO.zmax = PLOT.lithoThickness(1,2) /2; %depth in [km]
LITHO.Tisovalue = 700; %[K]; for lithosphere definition
LITHO.zmax      = 150;  %[km]; for lithosphere definition
LITHO.zmin      = 5;  %[km]; for lithosphere definition
LITHO.gridpoints= 0; %just to define it as it is used here
if SWITCH.dim || SWITCH.dimensionalInput
    z2dx = GRID.Z_3D/1e3; %[km]
    if ~strcmp(GRID.Xdim,'km'); warning(['f_lithoThickness input should be in [',GRID.Xdim,']!']); end
else
    z2dx = GRID.Z_3Dp; %[nd]
    LITHO.zmax      = LITHO.zmax *1e3/SETUP.D_dim; %from [km] to [nd]
    LITHO.zmin      = LITHO.zmin *1e3/SETUP.D_dim; %from [km] to [nd]
end
[LITHO] = f_lithoThickness(T_3D,z2dx,LITHO); % derive lithosphere thickness by T contour:

%% PROBLEM CHECK
if min(isnan(LITHO.thickness(:)))==1 %all NaN values
    warning(['LITHO.zmax = ',num2str(LITHO.zmax),' too shallow: consider increasing!'])
end

if strcmp(GRID.Dim,'2-D')   % 2-D
    % get horizontal velocities at these depths
    vh_plate        = zeros(1,size(LITHO.gridpoints,1))*NaN;
    x2d_plate       = vh_plate;
    z2d_plate   	= vh_plate;
    for ix=1:size(LITHO.gridpoints,1)
        if isnan(LITHO.gridpoints(ix,1))
            vh_plate(1,ix) = NaN;
            x2d_plate(1,ix) = NaN; %with NaN values
            z2d_plate(1,ix) = NaN; %with NaN values
            continue
        end
        vh_plate(1,ix)  = VH_3D(ix,1,LITHO.gridpoints(ix,1));
        x2d_plate(1,ix) = x2d(ix,1,LITHO.gridpoints(ix,1)); %with NaN values
        z2d_plate(1,ix) = z2d(ix,1,LITHO.gridpoints(ix,1)); %with NaN values
    end
    
elseif strcmp(GRID.Dim,'3-D') %3-D
    % get normal stress at these depths
    vh_plate    = zeros(size(LITHO.gridpoints,1),size(LITHO.gridpoints,2))*NaN;
    x2d_plate  	= vh_plate;
    y2d_plate	= vh_plate;
    z2d_plate 	= vh_plate;
    for ix=1:size(LITHO.gridpoints,1)
        for iy=1:size(LITHO.gridpoints,2)
            if isnan(LITHO.gridpoints(ix,iy,1))
                vh_plate(ix,iy) = NaN;
                x2d_plate(ix,iy) = NaN; %with NaN values
                y2d_plate(ix,iy) = NaN; %with NaN values
                z2d_plate(ix,iy) = NaN; %with NaN values
                continue
            end
            vh_plate(ix,iy) = VH_3D(ix,iy,LITHO.gridpoints(ix,iy));
            x2d_plate(ix,iy) = x2d(ix,iy,LITHO.gridpoints(ix,iy)); %with NaN values
            y2d_plate(ix,iy) = y2d(ix,iy,LITHO.gridpoints(ix,iy)); %with NaN values
            z2d_plate(ix,iy) = z2d(ix,iy,LITHO.gridpoints(ix,iy)); %with NaN values
        end
    end
end

NanLocations = find(isnan(vh_plate));

%------------------------
% SMOOTHING  maybe doesn't work yet....
%------------------------
PLATE.Vh_smooth = logical(0);
if strcmp(GRID.Dim,'2-D') && PLATE.Vh_smooth
    vh_smooth_1 = vh_plate;
    for jj=1:2
        vh_smooth_2(1,:) = smooth(vh_smooth_1(1,:),5,'moving');
        vh_smooth_1 = vh_smooth_2;
    end
    vh_plate = vh_smooth_2;
    
    %re-insert NaN values
    vh_plate(1,NanLocations) = NaN;
    %------------------------
end

%% WRITE INFOS
if PLOT.loop_field==1; disp(['   > plate velocity   tracked at ~',num2str(mean(LITHO.thickness(:)),4),' km depth']); end
if PLOT.loop_field==1; disp(['   >    and between d = ',num2str(min(LITHO.thickness(:)),4),' and ',num2str(max(LITHO.thickness(:)),4),' km depth']); end

%% COUNT SUBPLOTS
PLOT.nrSubplot = PLOT.nrSubplot+1;

% PLOT HORIZONTAL PLATE VELOCITY ---------------------------------------------------
if strcmp(GRID.Dim,'2-D')   % 2-D
    %% figure...
    figure(1)
    %% SUBPLOT LAYOUT...
%     if iloopComp==1;
        %subplot layout...
        SPOS.task   = 'createSubplot';
%         if isfield(SAVE,'PlotInPlot_FIELD2D_hax')
%             SPOS.haxPlotInPlot = SAVE.PlotInPlot_FIELD2D_hax;
%         end
        [SP,SAVE] = f_subplotPosition(SPOS,PLOT,SWITCH,SAVE);
        
        %% CURRENT AXIS
        AXcurrent = gca; %save current axes handle
%     end
    
    %% PLOTTING HORIZONTAL PLATE VELOCITY ----------------------------------------------
    hold on
    PLATE.hLineVhplate = plot(x2d_plate,vh_plate,'Color',lineCOLOUR0,'LineWidth',lineWIDTH0);
    hold on
    
    %     xpoints = x2d_plate;
    %     upper = vh_plate;
    %     if ~strcmp(TOPO.areaFill,'none')
    %         if strcmp(TOPO.areaFill,'down')
    %             color = lineCOLOUR0;
    %             lower = zeros(size(upper))+(min(upper)-1/10*(max(upper)-min(upper)));
    %             if TOPO.indicateComponents && PLOT.topoLOWval<lower(1,1);
    %                 lower = zeros(size(upper))+PLOT.topoLOWval;
    %             end
    %             if SWITCH.Colorbar(1,2); lower = zeros(size(upper))+FIELD.cColorbarMIN; end %constant colorbar
    %             if SWITCH.plotDifference && strcmp(TOPO.difference,'diff'); lower = lower*0; end %in relation to 0 topography
    %
    %         elseif strcmp(TOPO.areaFill,'updown')
    %             color = lineCOLOUR0;
    %             lower = zeros(size(upper));
    %         else
    %             error(['TOPO.areaFill mode ',TOPO.areaFill,'not recognised!'])
    %         end
    %     end
    
    
    %------------------------------------------------------------------
    VARIA.zlabelName	= 'Velocity';
    VARIA.zlabelDim     = FIELD.dim;
    VARIA.task          = 'create annotation strings';
    [PLOT,VARIA] = f_varia(VARIA,FIELD,GRID,SWITCH,PLOT,STYLE,SAVE);

    ylabel(PLOT.ylabel)
    xlabel(PLOT.xlabel)
    VARIA.task          = 'make title';
    [PLOT,VARIA] = f_varia(VARIA,FIELD,GRID,SWITCH,PLOT,STYLE,SAVE);
    
    axis tight
    
    if SWITCH.Colorbar(1,2); ylim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
    if SWITCH.setAxisLimit
        if size(SWITCH.axisLimit,1)>1  %more than one axis-zoom value
            xlim(SWITCH.axisLimit(PLOT.loopCase,1:2));
        else
            xlim(SWITCH.axisLimit(1,1:2));
        end
    end
    %set(AXcurrent,'YGrid','on')
    grid on
    box on
    %set tickmarks out- or inside
    set(gca,'TickDir',SWITCH.tickDir)
    
    if SWITCH.texting
        if SWITCH.dim || SWITCH.dimensionalInput
            text(min(xlim),max(ylim),['min val: ',num2str(min(vh_plate(:)),2)],'HorizontalAlignment','left','VerticalAlignment','bottom','FontSize',8)
            text(max(xlim),max(ylim),['max val: ',num2str(max(vh_plate(:)),2)],'HorizontalAlignment','right','VerticalAlignment','bottom','FontSize',8)
            disp(['   max.vplate: ',num2str(max(vh_plate)),' / min.vplate: ',num2str(min(vh_plate))])
        else
        end
    end
    
    % FIGURE SIZE & POSITION ==================================
    figure(1)
    hold on
    
    % COLORBAR ==================================
    colorbar;   %define dummy colorbar
    PLOT.cb = NaN; 	%this is a flag if no colorbar is used
    
    %SIMPLIFY FIGURE ==================================
    if SWITCH.simplify
        %SET AXES ASPECT RATIO ----
        XaxisAR = GRID.aspectRatio(1);
        YaxisAR = 1;
        ZaxisAR = 1;
        set(gca,'PlotBoxAspectRatio',[XaxisAR YaxisAR ZaxisAR])
        %--------------------------
        
        %GATHER INFORMATION ABOUT SUBPLOT LAYOUT
        PLOT.spcurrent          = SP.current;
        PLOT.sp_chax            = AXcurrent;
        if exist('haxZ','var'); PLOT.sp_chaxz = haxZ; else; PLOT.sp_chaxz = NaN; end
        PLOT.sp_ccb             = PLOT.cb;   %colorbar handle
        PLOT.title              = PLOT.titleStringCurrent;  	%title string
        
        [PLOT] = f_designLayout(SWITCH,PLOT,GRID,FIELD);
    end
    
elseif strcmp(GRID.Dim,'3-D') %3-D
    AXcurrent = gca; %just to be defined
    
    VARIA.zlabelName3D	= 'Velocity';
    VARIA.zlabelDim     = FIELD.dim;
    VARIA.task          = 'create annotation strings';
    [PLOT,VARIA] = f_varia(VARIA,FIELD,GRID,SWITCH,PLOT,STYLE,SAVE);
    
    xi_plot = x2d_plate(:,1,1);  %[km]
    yi_plot = y2d_plate(1,:,1);  %[km]
    zi_plot = vh_plate;  %[km]
    %     if i_field==2 %plot topo smooth ==========================
    %         F = [.05 .1 .05; .1 .4 .1; .05 .1 .05];
    %         for jj=1:20 %smoothing
    %             ZC = conv2(zi_plot,F,'same');
    %             zi_plot=ZC;
    %         end
    %     end %plot topo smooth ==========================
    
    surf(yi_plot,xi_plot,zi_plot,'EdgeColor','none')
    % contour(xi,yi,zi)
    if ~TOPO.ascii
        axis ij
    end
    axis tight
    xlabel(PLOT.xlabel)
    ylabel(PLOT.ylabel)
    zlabel(PLOT.zlabel)

    VARIA.task          = 'make title';
    [PLOT,VARIA] = f_varia(VARIA,FIELD,GRID,SWITCH,PLOT,STYLE,SAVE);
    
    if SWITCH.Colorbar(1,2); zlim([FIELD.cColorbarMIN FIELD.cColorbarMAX]); end
    
    clearvars low high tix tiy
end

if isfield(PLOT,'hax'); nr_hax = size(PLOT.hax,1)+1; else; nr_hax = 1; end

%% FUNCTION OUTPUT
PLOT.hax(nr_hax,1)  = AXcurrent;

%indicate axis handle as graph subplot
SAVE.graphPlotHandles = [SAVE.graphPlotHandles; AXcurrent]; %indicate axis handle as graph subplot
SAVE.PlotHandles = [SAVE.PlotHandles; AXcurrent];






