
%%                                                      PARAMETER FILE 2-D
%                                                             for STAGplot

clear; clf;
SAVE.StartNum       =   14;
SAVE.StepNum        =   1;
SAVE.EndNum         =   14;      %set big in order to continue to last file, set SAVE.StartNum==SAVE.EndNum to write only one file

for iLoop=SAVE.StartNum:SAVE.StepNum:SAVE.EndNum
clearvars -except iLoop SAVE; if ~exist('f_defaults','file'); f_INSTALL; end
    [IN,PLOT,SWITCH,TOPO,STYLE,SAVE] = f_defaults(SAVE); %get default variables

    %% INPUT FILE(S)
    IN.name                     =   { 'test'  };                   %filename; it's size controls the # of subplots
    IN.number                   =   [   iLoop  	1 ];                       %filenumber (use either iLoop or specific number)
    IN.parameter                =   [  	11      11 ];                      %parameter dimensionalisation (see f_dimParameter.m)
    IN.folder                   =   {'/work/plotTest/' '/work/plotTest/'};  %file directory
%     PLOT.titleString            =   {'XXX' 'XXX' 'XXX'  };
%     PLOT.legendString           =   {'XXX' 'XXX' 'XXX'  };

    %% DIMENSIONALISATION
    SWITCH.dim                  =   logical(1);   	%converts to dimensional output as set in f_dimParameter.m
    SWITCH.modelSetup           =   'standard';   	%general model parameter setup; see f_dimParameter.m

    %% SUBPLOT LAYOUT
%    PLOT.subplotLayout          =   [2 2];        %manually set subplot layout; only valid if uncommented; [z x]
    PLOT.reverseLayout          =   false;          %e.g., plot 3x2 instead of 2x3
    SWITCH.timeEvolution        =   logical(0);     SWITCH.timeDirection = 'topbot'; %'topbot', 'leftright'
    SWITCH.insertRectangles     =   logical(1);     %adds light rectangles to connect subplots

    %% POSITIONING
    PLOT.shiftLeft              =   0;              %shift subplot positions closer or further away from each other
    PLOT.shiftUpward            =   0;          
    
    %% COLORBAR
    SWITCH.Colorbar             =   logical(1);     
        IN.constantColorbar     =   logical(1);  
        SWITCH.cbarLimitIndicTop=   [0]; SWITCH.cbarLimitColorTop = [0.81 0.81 0.81]; %adds specific color to top/bot
        SWITCH.cbarLimitIndicBot=   [0]; SWITCH.cbarLimitColorBot = [0.81 0.81 0.81]; %indicating exceeding values (only one number sets it for all plots, otherwise specify for every subplot using [0 1 0 ...])
%     %to set the min/max colorbar values of each field use e.g.:
%     IN.T_min                =   300;
%     IN.T_max                =   1150;
%     IN.topo_min             =   -0.3;
%     IN.topo_max             =   0.3;
%     %as outlined in f_defaults.m
%     IN.eta_max                =   1e24;
%     IN.eta_min                =   1e20;
   
    %% PLOT STYLING
    SWITCH.stylePlots           =   logical(1);     %style plot
    SWITCH.styleBackground      =   logical(1);  	%style plot background of graph supplots
    SWITCH.styleLegend          =   logical(1);     %style legends
    SWITCH.simplify             =   logical(1);     %simplify plot layout
    
    %axes
    SWITCH.setAxisLimit         =   logical(0);     SWITCH.axisLimit = [500 1300 -5 200; 1500 2300 -5 200; ...
                                                                500 1300 -5 200; 1600 2400 -5 200];   %zoom for big plots
    %colours
    STYLE.colorMode             =   'light';        %'light' or 'dark' background
    
    %% ANNOTATIONS
    SWITCH.annotation           =   logical(1);     
        STYLE.annotationLocation=   'botLeft';        %e.g., 'topOutTop','topOutCorner','topLeft','botLeft','topRight','botRight'
        PLOT.annotation         =   {'a' 'b' 'c' 'd' 'e' 'f' 'g' 'h' 'i' 'j' 'k' 'l' 'm' 'n' 'o' 'p'};  %subplot annotation strings
        PLOT.annIfMoreThanOne   =   logical(1);     %add annotation only if more than 1 subplot
    SWITCH.title                =   logical(1);     
        PLOT.titleOnlyTime      =   logical(0);   	%for a title that includes only time
%         PLOT.titleString      =   {'title 1'  'title 2' 'title 3' '' '' '' '' '' '' '' '' ''  };	%adds manual title string if uncommented
    SWITCH.cylindricalCenterText =  logical(1);      %adds #gridpoints to the center of the cylinder
    
    %% PLOT ADDITIONS
    PLOT.zoom                   =   logical(0);     %adds an additional plot for a close up
        PLOT.zoomVal            =   [2500 3500 -50 500 ; 900 1900 -50 500 ; 1300 2300 -50 500]; %...with the corresponding values  
    
    %% POST-PROCESSING
    SWITCH.plateDiagnostics     =   logical(0);
    SWITCH.mantleDiagnostics    =   logical(0);
    PLOT.indicateTrench         =   logical(0);
    PLOT.indicateRidge          =   logical(0);
    PLOT.indicateUpperPlate     =   logical(0);
    PLOT.indicateLowerPlate     =   logical(0);
    PLOT.indicatePlateCore      =   logical(0);     %depth of the plate core
    PLOT.indicateSlabDip        =   logical(0);
    PLOT.indicateSlabTip        =   logical(0);
    PLOT.indicatePlateFit       =   logical(0);     %fit of the subducting plate
    PLOT.indicateUPtilt         =   logical(0);     %upper-plate tilt
    PLOT.indicateBending        =   logical(0);
    PLOT.indicatePlumes         =   logical(0);     %only for yy cases 
       	PLOT.pHot               =   0.4;            %fraction of difference Tmax-Tmean and Tmin-Tmean, resp. (T_threshold = Tmean+p_hot*(Tmax-Tmean) )
        PLOT.pCold              =   0.4;            %fraction of difference Tmax-Tmean and Tmin-Tmean, resp. (T_threshold = Tmean+p_hot*(Tmax-Tmean) )

    %% SAVING FIGURE
    SAVE.Plot                   =   logical(0);     %saves plot directly to directory
        SAVE.png                =   logical(1);     SAVE.pngResolution = '-m4.0';	
        SAVE.jpg                =   logical(0); 
        SAVE.eps                =   logical(0); 
        SAVE.overwrite          =   logical(0);
        SAVE.writeDirectory     =   'auto';         %'auto': save to standard folder (.../+im/...); otherwise use e.g., '/work/stagyy/'
        
    %% SAVING MOVIE
    SAVE.Movie                  =   logical(0);     %saves movie directly to directory
        SAVE.avi                =   logical(1);
        SAVE.mj2                =   logical(0);
        SAVE.mp4                =   logical(0);
        SAVE.m4v                =   logical(0);
        SAVE.movFrameRate       =   10;            	%10 (default) | frames per second
        SAVE.movQuality         =   75;             %75 (default) | integer in the range [0,100]
        
    %% SAVE DATA
    SAVE.field                  =   logical(0);     SAVE.mat = logical(1); SAVE.dat = logical(0);  %saves plotted 2-D/3-D field according to f_saveField.m
    SAVE.tectonicData           =   logical(0);     %saves tectonic data (see list of data in STAGplot.m)
    TOPO.saveData               =   logical(0);     %saves topo: [x, topo, topoSmooth]
        
    %% PERFORMANCE
    SWITCH.quickRun             =   logical(0);     %adjust parfile switches for quick runtime to e.g. save data efficiently

    %% SPECIAL PLOTTING BEHAVIOUR
    SWITCH.PlotInPlot           =   logical(0); 	%for every field plots data from all files onto same plot  *not implemented for all fields yet*
    SWITCH.plotGraphVsTime      =   logical(0);     %plots in 2-D, a selected graph (x) vs. time (y)  *only for topography, yet*
    SWITCH.plotDifference       =   logical(0);     %plots difference between two fields
        
    %% FIELDS TO PLOT
    PLOT.Temperature            =   logical(1);
    PLOT.RegionalResidualT      =   logical(0);
    PLOT.HorizResidualT         =   logical(0);
    PLOT.HorizBandResidualT     =   logical(0);
    PLOT.GlobalResidualT        =   logical(0);
    PLOT.Composition            =   logical(0);
    PLOT.Density                =   logical(0);
    PLOT.Viscosity              =   logical(1);  IN.eta_log = logical(1);
    
    PLOT.Velocity               =   logical(0);
    PLOT.VelocityX              =   logical(0);
    PLOT.VelocityZ              =   logical(0);
    PLOT.UpDownWelling          =   logical(0);  %plots active and passive up- and down-welling
    PLOT.Pressure               =   logical(0);  %total pressure
    PLOT.HeatFlux               =   logical(0);
    PLOT.StrainRate             =   logical(0);  IN.edot_log=logical(0);   %strain rate
    PLOT.Stress                 =   logical(0);  IN.str_log=logical(0);  %logarithmic stress
    PLOT.NormalStress           =   logical(0);  %sigma_zz actually

    PLOT.Topo                   =   logical(0);  TOPO.ascii=logical(0); TOPO.cmb=logical(0); TOPO.surf=logical(1);
        TOPO.indicateComponents = 	logical(0);  %indicate isostatic & residual component
    PLOT.IsoTopo                =   logical(0);
    PLOT.ResTopo                =   logical(0);
    PLOT.DynTopo                =   logical(0);
    PLOT.Geoid                  =   logical(0);  TOPO.GEOIDcmb=logical(0); TOPO.GEOIDsurf=logical(1);
    
    PLOT.DefMechanism           =   logical(0);
    PLOT.Toroidal               =   logical(0);
    PLOT.Poloidal               =   logical(0);
        
    PLOT.Basalt                 =   logical(0);  %individual compositions
    PLOT.Harzburgite            =   logical(0);
    PLOT.ContCrust              =   logical(0);
    PLOT.Air                    =   logical(0);
    PLOT.Primordial             =   logical(0);
    PLOT.Water                  =   logical(0);
    PLOT.Melt                   =   logical(0);
    
    %% GRAPHS TO PLOT
    PLOT.ParTable               =   logical(0);  %plots a table with dynamic parameters
    PLOT.PlateSketch            =   logical(0);  %plot sketch of plates with subduction parameters indication
    PLOT.PlateVh                =   logical(0);
    PLOT.IsolineTopo            =   logical(0);  %e.g., for LAB topography; uses same parameter input as for lithoThickness
    PLOT.CustomGraph            =   logical(0);  %plot graph of any data versus any data (that has been saved previously with StagLab)
        PLOT.CustomGraphName    =   {'custom'};  %indicate which graph(s) to plot, use 'custom' for a custom graph specified in f_plotCustomGraph.m or any pre-specified graph there
    
    %% SPECIAL PLOTS
    PLOT.Grid                   =   logical(0);  PLOT.nCoarserGrid 	= 1; %plots grid
    PLOT.Streamfunction       	=   logical(0);  PLOT.streamdata = 'psi'; %psi (streamfunction) or phi (v-potential)
     
    %% FIELD PLOT ADDITIONS
    IN.grid_T                   =   logical(0);  % add grid to fields
    IN.grid_eta                 =   logical(0);
    IN.grid_str                 =   logical(0);
    IN.grid_edot                =   logical(0);
    
    IN.streamfun_T              =   logical(0);  % add streamfunction plot to fields
    IN.streamfun_eta            =   logical(0);  IN.streamNumContours = 17;
    IN.streamfun_str            =   logical(0);
    IN.streamfun_rho            =   logical(0);  
    IN.streamfun_v              =   logical(0);
    IN.streamfun_edot           =   logical(0);

    IN.quiver_T                 =   logical(0);  % add quiver plot to fields
    IN.quiver_eta               =   logical(0);  SWITCH.quiverNumArrows = 'auto'; %'auto' or 'manual': reduces number of arrows
    IN.quiver_str               =   logical(0);  IN.quiverNumDel    = 14;
    IN.quiver_psi               =   logical(0);  IN.quiverScale     = 17;
    IN.quiver_rho               =   logical(0);
    IN.quiver_nstr              =   logical(0);
    IN.quiver_edot              =   logical(0);
    
    IN.defmech_T                =   logical(0);  %1: diffusion creep, 2: dislocation creep, 3: plasticity, 4: visc. cutoff
    IN.defmech_eta              =   logical(0);  IN.defmechContours	= [2 3 4];  %1.3: 1/3, 1.1: 1/10 of weakening from dislocation creep
    IN.defmech_str              =   logical(0);
    IN.defmech_edot             =   logical(0);
    
    IN.lithoThickness_T         =   logical(0);  PLOT.LTfieldContour= 'Temperature';
    IN.lithoThickness_eta       =   logical(0);  IN.lithoTisovalue 	= 1550; 
    IN.lithoThickness_nstr      =   logical(0);  IN.lithozmax     	= 500;
    
    IN.fieldContour_T           =   logical(0);  PLOT.fContourField	= 'Temperature';
    IN.fieldContour_eta         =   logical(0);  IN.fContourIsovalue= 1600;
    IN.fieldContour_nstr        =   logical(0);
    IN.fieldContour_vx          =   logical(0);
    IN.fieldContour_str         =   logical(0);
    IN.fieldContour_edot        =   logical(0);
    
    IN.princStress_T            =   logical(0);  % add quiver plot to fields
    IN.princStress_eta          =   logical(0);  SWITCH.princStressNumArrows = 'auto'; %'auto' or 'manual': reduces number of arrows
    IN.princStress_str          =   logical(0);  IN.princStressNumDel    = 5;
    IN.princStress_psi          =   logical(0);  IN.princStressScale     = 2;
    IN.princStress_rho          =   logical(0);
    IN.princStress_nstr         =   logical(0);
    IN.princStress_edot         =   logical(0);
    
    IN.plume_T                  =   logical(0);	 % add plume plot addition to fields
    IN.plume_eta                =   logical(0);
    IN.plume_str                =   logical(0);
    IN.plume_rho                =   logical(0);
    IN.plume_v                  =   logical(0);
    IN.plume_edot               =   logical(0);
    
    TOPO.field                  =   logical(0);  % add topography to field plots
        TOPO.line               =   logical(1); 
        TOPO.area               =   logical(1); 
    
        
    % //////////////////////////////////////
    %           run main routine
    [SAVE] = STAGplot(IN,PLOT,SWITCH,TOPO,STYLE,SAVE);
    % //////////////////////////////////////
    
    if SAVE.LastFile; break; end %last file reached
end
